@@ -309,6 +309,10 @@ class ApproxDistinct(Func):
     arg_types = {'this': True, 'accuracy': False}
 
 
+class ArrayAgg(Func):
+    arg_types = {'this': True}
+
+
 class Count(Func):
     arg_types = {'this': False, 'distinct': False}
 
@@ -319,3 +323,27 @@ class If(Func):
 
 class JSONPath(Func):
     arg_types = {'this': True, 'path': True}
+
+
+class StrToTime(Func):
+    arg_types = {'this': True, 'format': True}
+
+
+class StrToUnix(Func):
+    arg_types = {'this': True, 'format': True}
+
+
+class TimeToStr(Func):
+    arg_types = {'this': True, 'format': True}
+
+
+class TimeToUnix(Func):
+    arg_types = {'this': True}
+
+
+class UnixToStr(Func):
+    arg_types = {'this': True, 'format': True}
+
+
+class UnixToTime(Func):
+    arg_types = {'this': True}
